==> qtjambi-qt3drender-debuginfo-macos-5.15.18.jar: sources/QtJambi3DRender/QTextureGenerator_shell.cpp <==
#include "QTextureGenerator_shell.h"
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

void deleter_Qt3DRender_QTextureGenerator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DRender::QTextureGenerator")
    Qt3DRender::QTextureGenerator *_ptr = reinterpret_cast<Qt3DRender::QTextureGenerator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTextureGenerator_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTextureGenerator_shell) ); }

jmethodID QTextureGenerator_shell::__shell_javaMethod(int pos) const { return QTextureGenerator_shell::__shell()->javaMethod(typeid(Qt3DRender::QTextureGenerator), pos); }

// emitting (writeShellConstructor)
QTextureGenerator_shell::QTextureGenerator_shell()
    : Qt3DRender::QTextureGenerator()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DRender::QTextureGenerator::QTextureGenerator_shell()", QTextureGenerator_shell::__shell())
    QTextureGenerator_shell::__shell()->constructed(typeid(Qt3DRender::QTextureGenerator));
}

// emitting (writeShellDestructor)
QTextureGenerator_shell::~QTextureGenerator_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DRender::QTextureGenerator::~Qt3DRender::QTextureGenerator()", QTextureGenerator_shell::__shell())
    QTextureGenerator_shell::__shell()->destructed(typeid(Qt3DRender::QTextureGenerator));
}

void QTextureGenerator_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTextureGenerator_shell*>(ptr)->QTextureGenerator_shell::__shell()->tryDeleteShell(typeid(Qt3DRender::QTextureGenerator));
}

// emitting Virtual overrides (virtualFunctions)
qintptr QTextureGenerator_shell::id() const
{

    if(JniEnvironment __jni_env{200}) {
        if(jobject __qt_this = __shell()->getJavaObjectLocalRef(__jni_env)){
            return qintptr(QtJambiAPI::getJavaObjectHashCode(__jni_env, __jni_env->GetObjectClass(__qt_this)));
        }else{
            __shell()->warnForMethod("Qt3DRender::QAbstractFunctor::id() const");
        }
    }

    return 0;
}

QSharedPointer<Qt3DRender::QTextureData> QTextureGenerator_shell::operator()()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QTextureGenerator::", QTextureGenerator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSharedPointer<Qt3DRender::QTextureData>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextureGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QTextureGenerator_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSharedPointer<Qt3DRender::QTextureData> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QTextureGenerator_shell::__shell()->warnForMethod("Qt3DRender::QTextureGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QTextureGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSharedPointer<Qt3DRender::QTextureData>();
        }
    }else{
        return QSharedPointer<Qt3DRender::QTextureData>();
    }
}

bool QTextureGenerator_shell::operator==(const Qt3DRender::QTextureGenerator& other0) const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QTextureGenerator::", QTextureGenerator_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextureGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_other0 = qtjambi_cast<jobject>(__jni_env, &other0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_other0);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_other0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QTextureGenerator_shell::__shell()->warnForMethod("Qt3DRender::QTextureGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QTextureGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return false;
        }
    }else{
        return false;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QTextureGenerator_access::__qt_invoke(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QTextureGenerator::operator()()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QTextureGenerator::operator()().";
    } else {
        QSharedPointer<Qt3DRender::QTextureData> __qt_return_value = operator()();
        return qtjambi_cast<jobject>(__jni_env, __qtjambi_scope, __qt_return_value);
    }
}

jboolean QTextureGenerator_access::__qt_equals_cref_Qt3DRender_QTextureGenerator_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const Qt3DRender::QTextureGenerator& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<Qt3DRender::QTextureGenerator>(__jni_env, other0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QTextureGenerator::operator==(const Qt3DRender::QTextureGenerator & other) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QTextureGenerator::operator==(const Qt3DRender::QTextureGenerator & other) const.";
    } else {
        bool __qt_return_value = operator==(__qt_other0);
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_Qt3DRender_QTextureGenerator_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    Qt3DRender::QTextureGenerator *__qt_this = new(__qtjambi_ptr) QTextureGenerator_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTextureGenerator_shell
void __qt_destruct_Qt3DRender_QTextureGenerator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DRender::QTextureGenerator")
    reinterpret_cast<QTextureGenerator_shell*>(ptr)->~QTextureGenerator_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DRender::QTextureGenerator::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QTextureGenerator_00024Impl_initialize_1native__Lio_qt_qt3d_render_QTextureGenerator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DRender::QTextureGenerator::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DRender_QTextureGenerator_0, sizeof(QTextureGenerator_shell), typeid(Qt3DRender::QTextureGenerator), true, &deleter_Qt3DRender_QTextureGenerator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// Qt3DRender::QTextureGenerator::operator()()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QTextureGenerator_00024Impl_00024ConcreteWrapper_invoke_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Qt3DRender::QTextureGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QTextureGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QTextureGenerator::operator()()", __qt_this)
        __java_return_value = static_cast<QTextureGenerator_access*>(__qt_this)->__qt_invoke(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QTextureGenerator_00024Impl_00024ConcreteWrapper_equals_1native_1cref_1Qt3DRender_1QTextureGenerator_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QTextureGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QTextureGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const", __qt_this)
        __java_return_value = static_cast<const QTextureGenerator_access*>(__qt_this)->__qt_equals_cref_Qt3DRender_QTextureGenerator_constfct(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DRender_QTextureGenerator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<Qt3DRender::QTextureGenerator>("Qt3DRender::QTextureGenerator", "io/qt/qt3d/render/QTextureGenerator");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "invoke", "()Lio/qt/qt3d/render/QTextureData;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "equals", "(Lio/qt/qt3d/render/QTextureGenerator;)Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DRender_QTextureGenerator, {
        ConstructorInfo(&__qt_construct_Qt3DRender_QTextureGenerator_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DRender_QTextureGenerator);
    registerSizeOfShell(typeId, sizeof(QTextureGenerator_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QTextureGenerator* _object = dynamic_cast<Qt3DRender::QTextureGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QTextureGenerator *object = reinterpret_cast<Qt3DRender::QTextureGenerator *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const Qt3DRender::QTextureGenerator *object = reinterpret_cast<const Qt3DRender::QTextureGenerator *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
    registerPolymorphyHandler(typeid(Qt3DRender::QAbstractFunctor), typeId, [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QAbstractFunctor *object = reinterpret_cast<Qt3DRender::QAbstractFunctor *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QTextureGenerator* _object = dynamic_cast<Qt3DRender::QTextureGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(Qt3DRender::QAbstractFunctor), int(reinterpret_cast<quintptr>(static_cast<Qt3DRender::QAbstractFunctor *>(reinterpret_cast<Qt3DRender::QTextureGenerator *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3drender-debuginfo-macos-5.15.20.jar: sources/QtJambi3DRender/QTextureGenerator_shell.cpp <==
#include "QTextureGenerator_shell.h"
#include <QtJambi/Cast>

// emitting (writeClassCodeInjections)
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

void deleter_Qt3DRender_QTextureGenerator(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DRender::QTextureGenerator")
    Qt3DRender::QTextureGenerator *_ptr = reinterpret_cast<Qt3DRender::QTextureGenerator *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTextureGenerator_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTextureGenerator_shell) ); }

jmethodID QTextureGenerator_shell::__shell_javaMethod(int pos) const { return QTextureGenerator_shell::__shell()->javaMethod(typeid(Qt3DRender::QTextureGenerator), pos); }

// emitting (writeShellConstructor)
QTextureGenerator_shell::QTextureGenerator_shell()
    : Qt3DRender::QTextureGenerator()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DRender::QTextureGenerator::QTextureGenerator_shell()", QTextureGenerator_shell::__shell())
    QTextureGenerator_shell::__shell()->constructed(typeid(Qt3DRender::QTextureGenerator));
}

// emitting (writeShellDestructor)
QTextureGenerator_shell::~QTextureGenerator_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DRender::QTextureGenerator::~Qt3DRender::QTextureGenerator()", QTextureGenerator_shell::__shell())
    QTextureGenerator_shell::__shell()->destructed(typeid(Qt3DRender::QTextureGenerator));
}

void QTextureGenerator_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTextureGenerator_shell*>(ptr)->QTextureGenerator_shell::__shell()->tryDeleteShell(typeid(Qt3DRender::QTextureGenerator));
}

// emitting Virtual overrides (virtualFunctions)
qintptr QTextureGenerator_shell::id() const
{

    if(JniEnvironment __jni_env{200}) {
        if(jobject __qt_this = __shell()->getJavaObjectLocalRef(__jni_env)){
            return qintptr(QtJambiAPI::getJavaObjectHashCode(__jni_env, __jni_env->GetObjectClass(__qt_this)));
        }else{
            __shell()->warnForMethod("Qt3DRender::QAbstractFunctor::id() const");
        }
    }

    return 0;
}

QSharedPointer<Qt3DRender::QTextureData> QTextureGenerator_shell::operator()()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QTextureGenerator::", QTextureGenerator_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSharedPointer<Qt3DRender::QTextureData>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextureGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QTextureGenerator_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSharedPointer<Qt3DRender::QTextureData> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QTextureGenerator_shell::__shell()->warnForMethod("Qt3DRender::QTextureGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QTextureGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSharedPointer<Qt3DRender::QTextureData>();
        }
    }else{
        return QSharedPointer<Qt3DRender::QTextureData>();
    }
}

bool QTextureGenerator_shell::operator==(const Qt3DRender::QTextureGenerator& other0) const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("Qt3DRender::QTextureGenerator::", QTextureGenerator_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QTextureGenerator_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_other0 = qtjambi_cast<jobject>(__jni_env, &other0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_other0);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_other0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QTextureGenerator_shell::__shell()->warnForMethod("Qt3DRender::QTextureGenerator::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "Qt3DRender::QTextureGenerator::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return false;
        }
    }else{
        return false;
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QTextureGenerator_access::__qt_invoke(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QTextureGenerator::operator()()." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QTextureGenerator::operator()().";
    } else {
        QSharedPointer<Qt3DRender::QTextureData> __qt_return_value = operator()();
        return qtjambi_cast<jobject>(__jni_env, __qtjambi_scope, __qt_return_value);
    }
}

jboolean QTextureGenerator_access::__qt_equals_cref_Qt3DRender_QTextureGenerator_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const Qt3DRender::QTextureGenerator& __qt_other0 = QtJambiAPI::interfaceReferenceFromNativeId<Qt3DRender::QTextureGenerator>(__jni_env, other0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method Qt3DRender::QTextureGenerator::operator==(const Qt3DRender::QTextureGenerator & other) const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method Qt3DRender::QTextureGenerator::operator==(const Qt3DRender::QTextureGenerator & other) const.";
    } else {
        bool __qt_return_value = operator==(__qt_other0);
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// new QTextureGenerator()
void __qt_construct_Qt3DRender_QTextureGenerator(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextureGenerator()")
    Q_UNUSED(__java_arguments)
    Qt3DRender::QTextureGenerator *__qt_this = new(__qtjambi_ptr) QTextureGenerator_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// Qt3DRender::QTextureGenerator::QTextureGenerator()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QTextureGenerator_00024Impl_initialize_1native__Lio_qt_qt3d_render_QTextureGenerator_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DRender::QTextureGenerator::QTextureGenerator()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DRender_QTextureGenerator, sizeof(QTextureGenerator_shell), typeid(Qt3DRender::QTextureGenerator), true, &deleter_Qt3DRender_QTextureGenerator, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTextureGenerator_shell
void __qt_destruct_Qt3DRender_QTextureGenerator(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DRender::QTextureGenerator")
    reinterpret_cast<QTextureGenerator_shell*>(ptr)->~QTextureGenerator_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DRender::QTextureGenerator::operator()()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QTextureGenerator_00024Impl_00024ConcreteWrapper_invoke_1native__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Qt3DRender::QTextureGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QTextureGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QTextureGenerator::operator()()", __qt_this)
        __java_return_value = static_cast<QTextureGenerator_access*>(__qt_this)->__qt_invoke(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_render_QTextureGenerator_00024Impl_00024ConcreteWrapper_equals_1native_1cref_1Qt3DRender_1QTextureGenerator_1constfct__JJ)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const Qt3DRender::QTextureGenerator *__qt_this = QtJambiAPI::interfaceFromNativeId<Qt3DRender::QTextureGenerator>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("Qt3DRender::QTextureGenerator::operator==(Qt3DRender::QTextureGenerator)const", __qt_this)
        __java_return_value = static_cast<const QTextureGenerator_access*>(__qt_this)->__qt_equals_cref_Qt3DRender_QTextureGenerator_constfct(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DRender_QTextureGenerator(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<Qt3DRender::QTextureGenerator>("Qt3DRender::QTextureGenerator", "io/qt/qt3d/render/QTextureGenerator");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "invoke", "()Lio/qt/qt3d/render/QTextureData;", FunctionInfo::Abstract),
        FunctionInfo(/* 1 */ "equals", "(Lio/qt/qt3d/render/QTextureGenerator;)Z", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DRender_QTextureGenerator, {
        ConstructorInfo(&__qt_construct_Qt3DRender_QTextureGenerator, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DRender_QTextureGenerator);
    registerSizeOfShell(typeId, sizeof(QTextureGenerator_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QTextureGenerator* _object = dynamic_cast<Qt3DRender::QTextureGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QTextureGenerator *object = reinterpret_cast<Qt3DRender::QTextureGenerator *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const Qt3DRender::QTextureGenerator *object = reinterpret_cast<const Qt3DRender::QTextureGenerator *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
    registerPolymorphyHandler(typeid(Qt3DRender::QAbstractFunctor), typeId, [](void *ptr, qintptr& offset) -> bool {
            Qt3DRender::QAbstractFunctor *object = reinterpret_cast<Qt3DRender::QAbstractFunctor *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(Qt3DRender::QTextureGenerator* _object = dynamic_cast<Qt3DRender::QTextureGenerator*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids

    registerInterfaceOffset(typeId, typeid(Qt3DRender::QAbstractFunctor), int(reinterpret_cast<quintptr>(static_cast<Qt3DRender::QAbstractFunctor *>(reinterpret_cast<Qt3DRender::QTextureGenerator *>(0x10000000)))) - 0x10000000);

// BEGIN: enums and flags
// END: enums and flags
}
